@@ -2,9 +2,7 @@
 
 #include "plugin.h"
 
-zathura_error_t
-ps_page_init(zathura_page_t* page)
-{
+zathura_error_t ps_page_init(zathura_page_t* page) {
   if (page == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
@@ -19,7 +17,7 @@ ps_page_init(zathura_page_t* page)
 
   int page_width;
   int page_height;
-  spectre_page_get_size(ps_page, &(page_width), &(page_height));
+  spectre_page_get_size(ps_page, &page_width, &page_height);
 
   zathura_page_set_width(page, page_width);
   zathura_page_set_height(page, page_height);
@@ -28,9 +26,7 @@ ps_page_init(zathura_page_t* page)
   return ZATHURA_ERROR_OK;
 }
 
-zathura_error_t
-ps_page_clear(zathura_page_t* page, void* data)
-{
+zathura_error_t ps_page_clear(zathura_page_t* page, void* data) {
   if (page == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
