@@ -15,7 +15,7 @@
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t ps_document_open(zathura_document_t* document);
+zathura_error_t ps_document_open(zathura_document_t* document);
 
 /**
  * Closes and frees the internal document structure
@@ -24,7 +24,7 @@ GIRARA_HIDDEN zathura_error_t ps_document_open(zathura_document_t* document);
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t ps_document_free(zathura_document_t* document, void* spectre_document);
+zathura_error_t ps_document_free(zathura_document_t* document, void* spectre_document);
 
 /**
  * Saves the document to the given path
@@ -34,8 +34,7 @@ GIRARA_HIDDEN zathura_error_t ps_document_free(zathura_document_t* document, voi
  * @return ZATHURA_ERROR_OK when no error occurred, otherwise see
  *    zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t ps_document_save_as(zathura_document_t* document, void* spectre_document,
-                                                  const char* path);
+zathura_error_t ps_document_save_as(zathura_document_t* document, void* spectre_document, const char* path);
 
 /**
  * Returns a list of document information entries of the document
@@ -45,8 +44,8 @@ GIRARA_HIDDEN zathura_error_t ps_document_save_as(zathura_document_t* document,
  *   error occurred
  * @return List of information entries or NULL if an error occurred
  */
-GIRARA_HIDDEN girara_list_t* ps_document_get_information(zathura_document_t* document, void* spectre_document,
-                                                         zathura_error_t* error);
+girara_list_t* ps_document_get_information(zathura_document_t* document, void* spectre_document,
+                                           zathura_error_t* error);
 
 /**
  * Returns a reference to a page
@@ -55,7 +54,7 @@ GIRARA_HIDDEN girara_list_t* ps_document_get_information(zathura_document_t* doc
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t ps_page_init(zathura_page_t* page);
+zathura_error_t ps_page_init(zathura_page_t* page);
 
 /**
  * Renders a page onto a cairo object
@@ -66,8 +65,7 @@ GIRARA_HIDDEN zathura_error_t ps_page_init(zathura_page_t* page);
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t ps_page_render_cairo(zathura_page_t* page, void* spectre_page, cairo_t* cairo,
-                                                   bool printing);
+zathura_error_t ps_page_render_cairo(zathura_page_t* page, void* spectre_page, cairo_t* cairo, bool printing);
 
 /**
  * Frees a PostScript page
@@ -76,6 +74,6 @@ GIRARA_HIDDEN zathura_error_t ps_page_render_cairo(zathura_page_t* page, void* s
  * @return ZATHURA_ERROR_OK if no error occurred otherwise see
  *   zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t ps_page_clear(zathura_page_t* page, void* spectre_page);
+zathura_error_t ps_page_clear(zathura_page_t* page, void* spectre_page);
 
 #endif // PS_H
